summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetepassword.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopetepassword.cpp')
-rw-r--r--kopete/libkopete/kopetepassword.cpp34
1 files changed, 17 insertions, 17 deletions
diff --git a/kopete/libkopete/kopetepassword.cpp b/kopete/libkopete/kopetepassword.cpp
index 5fb1b847..57ff7da3 100644
--- a/kopete/libkopete/kopetepassword.cpp
+++ b/kopete/libkopete/kopetepassword.cpp
@@ -57,12 +57,12 @@ public:
}
/** Reference count */
int refCount;
/** Group to use for KConfig and KWallet */
const TQString configGroup;
/** Is the password being remembered? */
bool remembered;
- /** The current password in the KConfig file, or TQString() if no password there */
- TQString passwordFromKConfig;
+ /** The current password in the TDEConfig file, or TQString() if no password there */
+ TQString passwordFromTDEConfig;
/** The maximum length allowed for this password, or -1 if there is no limit */
uint maximumLength;
/** Is the current password known to be wrong? */
@@ -133,9 +133,9 @@ public:
// Before trying to read from the wallet, check if the config file holds a password.
// If so, remove it from the config and set it through KWallet instead.
TQString pwd;
- if ( mPassword.d->remembered && !mPassword.d->passwordFromKConfig.isNull() )
+ if ( mPassword.d->remembered && !mPassword.d->passwordFromTDEConfig.isNull() )
{
- pwd = mPassword.d->passwordFromKConfig;
+ pwd = mPassword.d->passwordFromTDEConfig;
mPassword.set( pwd );
return pwd;
}
@@ -143,8 +143,8 @@ public:
if ( mWallet && mWallet->readPassword( mPassword.d->configGroup, pwd ) == 0 && !pwd.isNull() )
return pwd;
- if ( mPassword.d->remembered && !mPassword.d->passwordFromKConfig.isNull() )
- return mPassword.d->passwordFromKConfig;
+ if ( mPassword.d->remembered && !mPassword.d->passwordFromTDEConfig.isNull() )
+ return mPassword.d->passwordFromTDEConfig;
return TQString();
}
@@ -276,7 +276,7 @@ public:
if ( mWallet && mWallet->writePassword( mPassword.d->configGroup, mNewPass ) == 0 )
{
mPassword.d->remembered = true;
- mPassword.d->passwordFromKConfig = TQString();
+ mPassword.d->passwordFromTDEConfig = TQString();
mPassword.writeConfig();
return true;
}
@@ -294,13 +294,13 @@ public:
"do you want to save the password in the <b>unsafe</b> configuration file instead?</qt>" ),
i18n( "Unable to Store Secure Password" ),
KGuiItem( i18n( "Store &Unsafe" ), TQString::fromLatin1( "unlock" ) ),
- TQString::fromLatin1( "KWalletFallbackToKConfig" ) ) != KMessageBox::Continue )
+ TQString::fromLatin1( "KWalletFallbackToTDEConfig" ) ) != KMessageBox::Continue )
{
return false;
}
}
mPassword.d->remembered = true;
- mPassword.d->passwordFromKConfig = mNewPass;
+ mPassword.d->passwordFromTDEConfig = mNewPass;
mPassword.writeConfig();
return true;
}
@@ -339,7 +339,7 @@ public:
kdDebug( 14010 ) << k_funcinfo << " clearing password" << endl;
mPassword.d->remembered = false;
- mPassword.d->passwordFromKConfig = TQString();
+ mPassword.d->passwordFromTDEConfig = TQString();
mPassword.writeConfig();
if ( mWallet )
mWallet->removeEntry( mPassword.d->configGroup );
@@ -380,14 +380,14 @@ Kopete::Password &Kopete::Password::operator=( Password &other )
void Kopete::Password::readConfig()
{
- KConfig *config = TDEGlobal::config();
+ TDEConfig *config = TDEGlobal::config();
config->setGroup( d->configGroup );
TQString passwordCrypted = config->readEntry( "Password" );
if ( passwordCrypted.isNull() )
- d->passwordFromKConfig = TQString();
+ d->passwordFromTDEConfig = TQString();
else
- d->passwordFromKConfig = KStringHandler::obscure( passwordCrypted );
+ d->passwordFromTDEConfig = KStringHandler::obscure( passwordCrypted );
d->remembered = config->readBoolEntry( "RememberPassword", false );
d->isWrong = config->readBoolEntry( "PasswordIsWrong", false );
@@ -395,7 +395,7 @@ void Kopete::Password::readConfig()
void Kopete::Password::writeConfig()
{
- KConfig *config = TDEGlobal::config();
+ TDEConfig *config = TDEGlobal::config();
if(!config->hasGroup(d->configGroup))
{
//### (KOPETE)
@@ -409,8 +409,8 @@ void Kopete::Password::writeConfig()
config->setGroup( d->configGroup );
- if ( d->remembered && !d->passwordFromKConfig.isNull() )
- config->writeEntry( "Password", KStringHandler::obscure( d->passwordFromKConfig ) );
+ if ( d->remembered && !d->passwordFromTDEConfig.isNull() )
+ config->writeEntry( "Password", KStringHandler::obscure( d->passwordFromTDEConfig ) );
else
config->deleteEntry( "Password" );
@@ -57,12 +57,12 @@ public:
/** Reference count */
int refCount;
- /** Group to use for KConfig and KWallet */
+ /** Group to use for TDEConfig and KWallet */
const TQString configGroup;
/** Is the password being remembered? */